pub type OrtThreadWorkerFn = unsafe extern "system" fn(ort_worker_fn_param: *mut c_void);Expand description
\brief Thread work loop function
Onnxruntime will provide the working loop on custom thread creation Argument is an onnxruntime built-in type which will be provided when thread pool calls OrtCustomCreateThreadFn